pytilities.geometry — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.geometry

All sorts of geometry trinkets

Contents

- functions
- DiscreteRectangle
- DiscreteVector
- ImmutableRectangle
- ImmutableVector
- Vector
- VerboseRectangleAspect
- VerboseVectorAspect
- _RectangleBase
- _VectorBase

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »